library(dplyr)

# This script contains the analysis of the temporal occupation data of species birdsong.
# It is necessary to run this script before the main analysis script, as the main
# analysis will not run past Step 17 without the values from this script.

# Temporal (Occupation) Analysis 
# Step 1: Reading in the occupation data
occA <- read.csv("/Volumes/TRISTAN/Dissertation/occA.csv")
occSM <- read.csv("/Volumes/TRISTAN/Dissertation/occSM.csv")
speciesA <- read.csv("/Volumes/TRISTAN/Dissertation/speciesA.csv")
speciesSM <- read.csv("/Volumes/TRISTAN/Dissertation/speciesSM.csv")

# Step 2: Replacing blank cells in the occupation data with zeroes
occA[is.na(occA)] <- 0
occSM[is.na(occSM)] <- 0
head(occA)
head(occSM)


# # Step 2.5: Table of occupation 

occsumsA <- numeric()
occsumsSM <- numeric()
occpcentsA <- numeric()
occpcentsSM <- numeric()

for (i in 1:57) {
  x <- sum(occA[i])
  y <- sum(occA[i])/54
  occsumsA <- append(occsumsA, x)
  occpcentsA <- append(occpcentsA, y)
}

for (i in 1:29) {
  x <- sum(occSM[i])
  y <- sum(occSM[i])/54
  occsumsSM <- append(occsumsSM, x)
  occpcentsSM <- append(occpcentsSM, y)
}

####

newoccA <- subset(occA, select = -c(which(occsumsA<5)))
newoccSM <- subset(occSM, select = -c(which(occsumsSM<5)))

####

is.num <- sapply(occtableA, is.numeric)

occtableA <- data.frame(unlist(speciesA), occsumsA, occpcentsA)
occtableSM <- data.frame(unlist(speciesSM), occsumsSM, occpcentsSM)

occtableA[is.num] <- lapply(occtableA[is.num], round, 3)
occtableSM[is.num] <- lapply(occtableSM[is.num], round, 3)

# Step 3: Calculate the total overlap of presence in time blocks between species
overlapfunctionA <- function(x) {
  #create empty vector
  vector <- numeric()
  for (i in 1:57) {
    y <- length(which(occA[x]==occA[i] & occA[x]==1))
    vector <- append(vector, y)
  }
  return(vector)
}

overlapfunctionSM <- function(x) {
  #create empty vector
  vector <- numeric()
  for (i in 1:29) {
    y <- length(which(occSM[x]==occSM[i] & occSM[x]==1))
    vector <- append(vector, y)
  }
  return(vector)
}

totaloverlapA <- data.frame(x = rep(0,57))
totaloverlapSM <- data.frame(x = rep(0,29))

for (y in 1:57) {
  totaloverlapA[,y] <- overlapfunctionA(y)
}

for (y in 1:29) {
  totaloverlapSM[,y] <- overlapfunctionSM(y)
}

names(totaloverlapA) <- unlist(speciesA)
names(totaloverlapSM) <- unlist(speciesSM)

# Step 4: Calculating percent overlap between species pairs
percentfunctionA <- function(x) {
  #create empty vector
  vector <- numeric()
  for (i in 1:57) {
    y <- length(which(occA[x]==occA[i] & occA[x]==1))
    z <- length(which(occA[x]==1))
    vector <- append(vector, 100*(y/z))
  }
  return(vector)
}

percentfunctionSM <- function(x) {
  #create empty vector
  vector <- numeric()
  for (i in 1:29) {
    y <- length(which(occSM[x]==occSM[i] & occSM[x]==1))
    z <- length(which(occSM[x]==1))
    vector <- append(vector, 100*(y/z))
  }
  return(vector)
}

percentoverlapA <- data.frame(x = rep(0,57))
for (y in 1:57) {
  percentoverlapA[,y] <- percentfunctionA(y)
}

percentoverlapSM <- data.frame(x = rep(0,29))
for (y in 1:29) {
  percentoverlapSM[,y] <- percentfunctionSM(y)
}

names(percentoverlapA) <- unlist(speciesA)
names(percentoverlapSM) <- unlist(speciesSM)

percentoverlapA[is.na(percentoverlapA)] <- 0
percentoverlapSM[is.na(percentoverlapSM)] <- 0

percentsA <- colMeans(occA)
percentsSM <- colMeans(occSM)

# Step 5: Calculating expected overlap (EO) (Planque & Slabbekoorn, 2008)
# *** Results from this step were not used in the final analysis ***
# Aleixo Expected Overlap Calculations
EOfunctionA <- function(x) {
  vector <- numeric()
  for (i in 1:57) {
    w <- percentsA[x]*percentsA[i]
    vector <- append(vector, w)
  }
 return(vector)
}

EO_A <- data.frame(x = rep(0,57))
for (y in 1:57) {
  EO_A[,y] <- EOfunctionA(y)
}

names(EO_A) <- unlist(speciesA)

# Santa Marta Expected Overlap Calculations
EOfunctionSM <- function(x) {
  vector <- numeric()
  for (i in 1:29) {
    w <- percentsSM[x]*percentsSM[i]
    vector <- append(vector, w)
  }
  return(vector)
}

EO_SM <- data.frame(x = rep(0,29))
for (y in 1:29) {
  EO_SM[,y] <- EOfunctionSM(y)
}

names(EO_SM) <- unlist(speciesSM)

# Step 6: Comparing actual and expected overlap between species pairs
AO_A <- totaloverlapA/54
ratioA <- AO_A/EO_A

AO_SM <- totaloverlapSM/54
ratioSM <- AO_SM/EO_SM

# # Step 7: Retrieving the mean occupation vector from each site

meanoccA <- numeric()
for (i in 1:57) {
  x <- mean(as.numeric(as.vector(occA[i,])))
  meanoccA <- append(meanoccA, x)
}

meanoccSM <- numeric()
for (i in 1:29) {
  x <- mean(as.numeric(as.vector(occSM[i,])))
  meanoccSM <- append(meanoccSM, x)
}

# # Step 8: Building a vector of temporal distances from the meanocc
# # (If the species differs greatly from the meanocc in a given time block, the absolute difference will tend to 1,
# # whereas if the species overlaps greatly with the meanocc in that block it will tend to 0. Our measure of temporal
# # distance is the sum of these block-by-block variances)

meantempdistA <- numeric()
for (i in 1:57) {
  x <- sum(abs(occA[i]-meanoccA))
  meantempdistA <- append(meantempdistA, x)
}

meantempdistSM <- numeric()
for (i in 1:29) {
  x <- sum(abs(occSM[i]-meanoccSM))
  meantempdistSM <- append(meantempdistSM, x)
}



meanoccA

